mysql.exceptions.server.Old_File_Format

Package mysql :: Package exceptions :: Module server :: Class Old_File_Format |
[hide private]
[frames] | no frames]

# Class Old_File_Format

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Old_File_Format

'%-.64s' has an old format, you should re-create the '%s' object(s). (New in 5.0.17.)

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`